@@ -23,6 +23,9 @@ class EvmNetData:
   EE_ORACLE_API_URL_KEY = 'EE_ORACLE_API_URL'
   EE_DEEPLOY_API_URL_KEY = 'EE_DEEPLOY_API_URL'
   EE_DAPP_API_URL_KEY = 'EE_DAPP_API_URL_KEY'
+  EE_DAPP_APP_URL_KEY = 'EE_DAPP_APP_URL'
+  EE_EXPLORER_APP_URL_KEY = 'EE_EXPLORER_APP_URL'
+  EE_DEEPLOY_APP_URL_KEY = 'EE_DEEPLOY_APP_URL'
 
 # endclass EvmNetData
 
@@ -528,7 +531,7 @@ EVM_NET_DATA = {
     EvmNetData.DAUTH_MND_ADDR_KEY               : "0x0C431e546371C87354714Fcc1a13365391A549E2",
     EvmNetData.DAUTH_PROXYAPI_ADDR_KEY          : "0xa2fDD4c7E93790Ff68a01f01AA789D619F12c6AC",
     EvmNetData.DAUTH_POAI_MANAGER_ADDR_KEY      : "0xa8d7FFCE91a888872A9f5431B4Dd6c0c135055c1",
-    EvmNetData.DAUTH_RPC_KEY                    : "https://base-mainnet.public.blastapi.io",
+    EvmNetData.DAUTH_RPC_KEY                    : "https://base-rpc.publicnode.com",
     EvmNetData.EE_GENESIS_EPOCH_DATE_KEY        : "2025-05-23 16:00:00",
     EvmNetData.EE_EPOCH_INTERVALS_KEY           : 24,
     EvmNetData.EE_EPOCH_INTERVAL_SECONDS_KEY    : 3600,
@@ -536,6 +539,9 @@ EVM_NET_DATA = {
     EvmNetData.EE_ORACLE_API_URL_KEY            : "https://oracle.ratio1.ai",
     EvmNetData.EE_DEEPLOY_API_URL_KEY           : "https://deeploy-api.ratio1.ai",
     EvmNetData.EE_DAPP_API_URL_KEY              : "https://dapp-api.ratio1.ai",
+    EvmNetData.EE_DAPP_APP_URL_KEY              : "https://app.ratio1.ai",
+    EvmNetData.EE_EXPLORER_APP_URL_KEY          : "https://explorer.ratio1.ai",
+    EvmNetData.EE_DEEPLOY_APP_URL_KEY           : "https://deeploy.ratio1.ai",
     EvmNetData.DAUTH_GET_ORACLES_ABI            : _DAUTH_ABI_GET_ORACLES,
   },
 
@@ -547,7 +553,7 @@ EVM_NET_DATA = {
     EvmNetData.DAUTH_MND_ADDR_KEY               : "0xa8d7FFCE91a888872A9f5431B4Dd6c0c135055c1",
     EvmNetData.DAUTH_PROXYAPI_ADDR_KEY          : "0xd1c7Dca934B37FAA402EB2EC64F6644d6957bE3b",
     EvmNetData.DAUTH_POAI_MANAGER_ADDR_KEY      : "0x68f825aA8fD4Af498c2998F4b165F103080574d4",
-    EvmNetData.DAUTH_RPC_KEY                    : "https://base-sepolia.public.blastapi.io",      
+    EvmNetData.DAUTH_RPC_KEY                    : "https://base-sepolia-rpc.publicnode.com",      
     EvmNetData.EE_GENESIS_EPOCH_DATE_KEY        : "2025-05-23 16:00:00",
     EvmNetData.EE_EPOCH_INTERVALS_KEY           : 24,
     EvmNetData.EE_EPOCH_INTERVAL_SECONDS_KEY    : 3600,
@@ -555,6 +561,9 @@ EVM_NET_DATA = {
     EvmNetData.EE_ORACLE_API_URL_KEY            : "https://testnet-oracle.ratio1.ai",
     EvmNetData.EE_DEEPLOY_API_URL_KEY           : "https://testnet-deeploy-api.ratio1.ai",
     EvmNetData.EE_DAPP_API_URL_KEY              : "https://testnet-dapp-api.ratio1.ai",
+    EvmNetData.EE_DAPP_APP_URL_KEY              : "https://testnet-app.ratio1.ai",
+    EvmNetData.EE_EXPLORER_APP_URL_KEY          : "https://testnet-explorer.ratio1.ai",
+    EvmNetData.EE_DEEPLOY_APP_URL_KEY           : "https://testnet-deeploy.ratio1.ai",
     EvmNetData.DAUTH_GET_ORACLES_ABI            : _DAUTH_ABI_GET_ORACLES,
   },
 
@@ -567,7 +576,7 @@ EVM_NET_DATA = {
     EvmNetData.DAUTH_MND_ADDR_KEY               : "0x17B8934dc5833CdBa1eF42D13D65D677C4727748",
     EvmNetData.DAUTH_PROXYAPI_ADDR_KEY          : "0xFcF04c9A67330431Af75a546615E4881BD8bdC78",
     EvmNetData.DAUTH_POAI_MANAGER_ADDR_KEY      : "0xCc7C4e0f4f25b57807F34227Fb446E68c8c36ce5",
-    EvmNetData.DAUTH_RPC_KEY                    : "https://base-sepolia.public.blastapi.io",
+    EvmNetData.DAUTH_RPC_KEY                    : "https://base-sepolia-rpc.publicnode.com",
     EvmNetData.EE_GENESIS_EPOCH_DATE_KEY        : "2025-06-30 07:00:00",
     EvmNetData.EE_EPOCH_INTERVALS_KEY           : 1,
     EvmNetData.EE_EPOCH_INTERVAL_SECONDS_KEY    : 3600,
@@ -575,6 +584,9 @@ EVM_NET_DATA = {
     EvmNetData.EE_ORACLE_API_URL_KEY            : "https://devnet-oracle.ratio1.ai",
     EvmNetData.EE_DEEPLOY_API_URL_KEY           : "https://devnet-deeploy-api.ratio1.ai",
     EvmNetData.EE_DAPP_API_URL_KEY              : "https://devnet-dapp-api.ratio1.ai",
+    EvmNetData.EE_DAPP_APP_URL_KEY              : "https://devnet-app.ratio1.ai",
+    EvmNetData.EE_EXPLORER_APP_URL_KEY          : "https://devnet-explorer.ratio1.ai",
+    EvmNetData.EE_DEEPLOY_APP_URL_KEY           : "https://devnet-deeploy.ratio1.ai",
     EvmNetData.DAUTH_GET_ORACLES_ABI            : _DAUTH_ABI_GET_ORACLES,
   },
 }
@@ -604,8 +616,8 @@ EVM_NET_CONSTANTS = {
       "0xai_A61eKDV1otIH6uWy3zDlbJNJUWayp1jAsirOuYxztf82",  # tr1s-02
     ],
     EvmNetConstants.EE_ORACLE_SYNC_USE_R1FS_KEY: False,  # Do not use R1FS for oracle sync in testnet.
-    EvmNetConstants.ORACLE_SYNC_BLOCKCHAIN_PRESENCE_MIN_THRESHOLD_KEY: 0.3,
-    EvmNetConstants.ORACLE_SYNC_ONLINE_PRESENCE_MIN_THRESHOLD_KEY: 0.4,
+    EvmNetConstants.ORACLE_SYNC_BLOCKCHAIN_PRESENCE_MIN_THRESHOLD_KEY: 0.15,
+    EvmNetConstants.ORACLE_SYNC_ONLINE_PRESENCE_MIN_THRESHOLD_KEY: 0.2,
   },
   EvmNetData.DEVNET: {
     EvmNetConstants.EE_NET_MON_01_SUPERVISOR_LOG_TIME_KEY: 60,  # Log every minute.
